==> jc-1.4.0.tar.gz: polyglot/lex/Operator.h <==
// public class polyglot.lex.Operator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8477263718ae715a polyglot_lex_Operator
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_Operator_H_
#define _JC_polyglot_lex_Operator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Operator$sub_refs	_jc_polyglot_lex_Operator$sub_refs;
typedef struct _jc_polyglot_lex_Operator$sub_nonrefs	_jc_polyglot_lex_Operator$sub_nonrefs;
typedef struct _jc_polyglot_lex_Operator$refs	_jc_polyglot_lex_Operator$refs;
typedef struct _jc_polyglot_lex_Operator$nonrefs	_jc_polyglot_lex_Operator$nonrefs;
typedef struct _jc_polyglot_lex_Operator$object	_jc_polyglot_lex_Operator$object;

typedef const struct _jc_polyglot_lex_Operator$vmethods	_jc_polyglot_lex_Operator$vmethods;
typedef const struct _jc_polyglot_lex_Operator$vtable	_jc_polyglot_lex_Operator$vtable;
typedef const struct _jc_polyglot_lex_Operator$vtype	_jc_polyglot_lex_Operator$vtype;

// Constructors
extern void _jc_polyglot_lex_Operator$method$_init$37e74d0be0d3e539(_jc_env *, struct _jc_polyglot_lex_Operator$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_Operator$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_Operator$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_Operator$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_Operator$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_Operator$object *);
};

// Vtable
struct _jc_polyglot_lex_Operator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Operator$vmethods	polyglot_lex_Operator;
};

// Vtype
struct _jc_polyglot_lex_Operator$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Operator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Operator$sub_refs {
	struct _jc_java_lang_String$object	*which;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Operator$refs {
    _jc_polyglot_lex_Operator$sub_refs	polyglot_lex_Operator;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Operator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Operator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Operator$sub_nonrefs	polyglot_lex_Operator;
};

// Object instance structure
struct _jc_polyglot_lex_Operator$object {
	_jc_polyglot_lex_Operator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Operator$vtype	*vtype;
	_jc_polyglot_lex_Operator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Operator$vtype _jc_polyglot_lex_Operator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Operator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Operator$class_object;

#endif	/* _JC_polyglot_lex_Operator_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/Operator.h <==
// public class polyglot.lex.Operator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8477263718ae715a polyglot_lex_Operator
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_Operator_H_
#define _JC_polyglot_lex_Operator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Operator$sub_refs	_jc_polyglot_lex_Operator$sub_refs;
typedef struct _jc_polyglot_lex_Operator$sub_nonrefs	_jc_polyglot_lex_Operator$sub_nonrefs;
typedef struct _jc_polyglot_lex_Operator$refs	_jc_polyglot_lex_Operator$refs;
typedef struct _jc_polyglot_lex_Operator$nonrefs	_jc_polyglot_lex_Operator$nonrefs;
typedef struct _jc_polyglot_lex_Operator$object	_jc_polyglot_lex_Operator$object;

typedef const struct _jc_polyglot_lex_Operator$vmethods	_jc_polyglot_lex_Operator$vmethods;
typedef const struct _jc_polyglot_lex_Operator$vtable	_jc_polyglot_lex_Operator$vtable;
typedef const struct _jc_polyglot_lex_Operator$vtype	_jc_polyglot_lex_Operator$vtype;

// Constructors
extern void _jc_polyglot_lex_Operator$method$_init$37e74d0be0d3e539(_jc_env *, struct _jc_polyglot_lex_Operator$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_Operator$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_Operator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_Operator$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_Operator$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_Operator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_Operator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Operator$vmethods	polyglot_lex_Operator;
};

// Vtype
struct _jc_polyglot_lex_Operator$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Operator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Operator$sub_refs {
	struct _jc_java_lang_String$object	*which;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Operator$refs {
    _jc_polyglot_lex_Operator$sub_refs	polyglot_lex_Operator;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Operator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Operator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Operator$sub_nonrefs	polyglot_lex_Operator;
};

// Object instance structure
struct _jc_polyglot_lex_Operator$object {
	_jc_polyglot_lex_Operator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Operator$vtype	*vtype;
	_jc_polyglot_lex_Operator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Operator$vtype _jc_polyglot_lex_Operator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Operator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Operator$class_object;

#endif	/* _JC_polyglot_lex_Operator_H_ */
